@@ -135,7 +135,7 @@ commonFG <- list(
         }
         else {
             ls_res <- flatten_df(ls_res)
-            ls_res_summary <- ls_res[, c("name", "link.type", "object.type", "object.num_attrs", "group.nlinks", "group.mounted", "dataset.rank",
+            ls_res_summary <- ls_res[, c("name", "link.type", "obj_type", "num_attrs", "group.nlinks", "group.mounted", "dataset.rank",
                                          "dataset.dims", "dataset.maxdims", "dataset.type_class", "dataset.space_class", "committed_type")]
             return(ls_res_summary)
         }
@@ -1166,6 +1166,12 @@ commonFGDT <- list(
             stop("Problem getting attribute name by index")
         }
         return(res$name)
+    },
+    attr_get_number=function() {
+        "This function implements the HDF5-API function H5Aget_num_attrs."
+        "Please see the documentation at \\url{https://support.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-NumAttrs} for details."
+        res <- .Call("R_H5Aget_num_attrs", self$id, PACKAGE="hdf5r")
+        return(res$return_val)
     }
 )
 
